@@ -73,6 +73,7 @@ int args_init(args_t *args)
      args->offline_root_pre_script_cmd = ARGS_DEFAULT_OFFLINE_ROOT_PRE_SCRIPT_CMD;
      args->offline_root_post_script_cmd = ARGS_DEFAULT_OFFLINE_ROOT_POST_SCRIPT_CMD;
      args->multiple_providers = 0;
+     args->nocheckfordirorfile = 0;
 
      return 1;
 }
@@ -229,16 +230,21 @@ void args_usage(char *complaint)
      fprintf(stderr, "\tinstall <pkg>		Download and install <pkg> (and dependencies)\n");
      fprintf(stderr, "\tinstall <file.ipk>	Install package <file.ipk>\n");
      fprintf(stderr, "\tconfigure [<pkg>]	Configure unpacked packages\n");
-     fprintf(stderr, "\tremove <pkg>		Remove package <pkg>\n");
-     fprintf(stderr, "\tflag <flags> <pkg> ...	Flag package(s) <pkg>\n");
-     fprintf(stderr, "\t <flags>=hold,noprune,user,ok	\n");
+     fprintf(stderr, "\tremove <pkg|regexp>	Remove package <pkg|packages following regexp>\n");
+     fprintf(stderr, "\tflag <flag> <pkg> ...	Flag package(s) <pkg>\n");
+     fprintf(stderr, "\t <flag>=hold|noprune|user|ok|installed|unpacked (one per invocation)	\n");
     
      fprintf(stderr, "\nInformational Commands:\n");
      fprintf(stderr, "\tlist    		List available packages and descriptions\n");
      fprintf(stderr, "\tfiles <pkg>		List all files belonging to <pkg>\n");
-     fprintf(stderr, "\tsearch <file>		Search for a package providing <file>\n");
-     fprintf(stderr, "\tinfo [pkg [<field>]]	Display all/some info fields for <pkg> or all\n");
-     fprintf(stderr, "\tstatus [pkg [<field>]]	Display all/some status fields for <pkg> or all\n");
+     fprintf(stderr, "\tsearch <file|regexp>		Search for a package providing <file>\n");
+#ifndef IPKG_LIB
+     fprintf(stderr, "\tinfo [pkg|regexp [<field>]]	Display all/some info fields for <pkg> or all\n");
+     fprintf(stderr, "\tstatus [pkg|regexp [<field>]]	Display all/some status fields for <pkg> or all\n");
+#else
+     fprintf(stderr, "\tinfo [pkg|regexp]		Display all info for <pkg>\n");
+     fprintf(stderr, "\tstatus [pkg|regexp]		Display all status for <pkg>\n");
+#endif
      fprintf(stderr, "\tdownload <pkg>		Download <pkg> to current directory.\n");
      fprintf(stderr, "\tcompare_versions <v1> <op> <v2>\n");
      fprintf(stderr, "\t                          compare versions using <= < > >= = << >>\n");
@@ -286,6 +292,9 @@ void args_usage(char *complaint)
      fprintf(stderr, "\t-test                   No action -- test only\n");
      fprintf(stderr, "\t-t	 	        Specify tmp-dir.\n");
      fprintf(stderr, "\t--tmp-dir 	        Specify tmp-dir.\n");
+     fprintf(stderr, "\n");
+     fprintf(stderr, "\tregexp could be something like 'pkgname*' '*file*' or similar\n");
+     fprintf(stderr, "\teg: ipkg info 'libstd*'  or ipkg search '*libop*' or ipkg remove 'libncur*'\n");
      /* -force-removal-of-essential-packages	Let ipkg remove essential packages. 
 	Using this option is almost guaranteed to break your system, hence this option
 	is not even advertised in the usage statement. */
